@@ -134,7 +134,7 @@ class Operation:
         """
         Display more informative names for the Operation class
         """
-        return u"%s(name='%s', needs=%s, provides=%s)" % (
+        return "%s(name='%s', needs=%s, provides=%s)" % (
             self.__class__.__name__,
             self.name,
             self.needs,
@@ -867,7 +867,7 @@ class operation(Operation):
         """
         Display more informative names for the Operation class
         """
-        return u"%s(name='%s', needs=%s, provides=%s, fn=%s)" % (
+        return "%s(name='%s', needs=%s, provides=%s, fn=%s)" % (
             self.__class__.__name__,
             self.name,
             self.needs,
