@@ -144,6 +144,7 @@ But see below that the dag is now using the functions we specified:
 
 
 import ast
+import re
 import inspect
 from operator import itemgetter, attrgetter
 from typing import (
@@ -191,13 +192,16 @@ def _ast_info_str(x):
     return f'lineno={x.lineno}'
 
 
-def _itemgetter(items, item_keys=()):
-    return tuple(items[i] for i in item_keys)
+def _itemgetter(sequence, keys=()):
+    if len(keys) == 1:
+        key = keys[0]
+        return sequence[key]
+    return tuple(sequence[i] for i in keys)
 
 
-def signed_itemgetter(*item_keys):
+def signed_itemgetter(*keys):
     """Like ``operator.itemgetter``, except has a signature, which we needed"""
-    return partialx(_itemgetter, item_keys=item_keys, _rm_partialize=True)
+    return partialx(_itemgetter, keys=keys, _rm_partialize=True)
 
 
 # Note: generalize? glom?
@@ -291,6 +295,35 @@ def node_kwargs_to_func_node_factory(node_kwargs) -> FuncNodeFactory:
     return partial(FuncNode, **node_kwargs)
 
 
+def _ensure_src_string(src):
+    if callable(src):
+        src = inspect.getsource(src)
+    return src
+
+
+def _remove_indentation(src):
+    m = re.match(r'\s+', src)
+    if m is not None:
+        indent = m.group(0)
+        indent_length = len(indent)
+
+        def gen():
+            for line in src.split('\n'):
+                if line.startswith(indent):
+                    yield line[indent_length:]
+
+        return '\n'.join(gen())
+    else:
+        raise RuntimeError(f'I found no indent!')
+
+
+def robust_ast_parse(src):
+    try:
+        return ast.parse(src)
+    except IndentationError:
+        return robust_ast_parse(_remove_indentation(src))
+
+
 def parse_assignment_steps(src):
     """
     Parse source code and generate tuples of information about it.
@@ -325,9 +358,8 @@ def parse_assignment_steps(src):
     Basically, these ast objects contain all we need to know about the (parsed) source.
 
     """
-    if callable(src):
-        src = inspect.getsource(src)
-    root = ast.parse(src)
+    src = _ensure_src_string(src)
+    root = robust_ast_parse(src)
     assert len(root.body) == 1
     func_body = root.body[0]
     # TODO: work with func_body.args to get info on interface (name, args, kwargs,
@@ -345,17 +377,21 @@ FactoryToFunc = Callable[[FuncNodeFactory], Callable]
 
 
 def src_to_func_node_factory(
-    src, names_used_so_far=None
+    src, exclude_names=None
 ) -> Iterator[Union[FuncNode, FuncNodeFactory]]:
-    """A generator of FuncNode factories from a src (string or object)."""
-    names_used_so_far = names_used_so_far or set()
+    """
+    :param src: Callable or string of callable.
+    :param exclude_names: Names to exclude when making func_nodes
+    :return:
+    """
+    exclude_names = set(exclude_names or set())
     for i, target_value in enumerate(parse_assignment_steps(src), 1):
         for node_kwargs in parsed_to_node_kwargs(target_value):
             node_kwargs['func_label'] = node_kwargs['name']
-            if node_kwargs['name'] in names_used_so_far:
+            if node_kwargs['name'] in exclude_names:
                 # need to keep names uniques, so add a prefix to (hope) to get uniqueness
                 node_kwargs['name'] += f'_{i:02.0f}'
-            names_used_so_far.add(node_kwargs['name'])
+            exclude_names.add(node_kwargs['name'])
             yield node_kwargs_to_func_node_factory(node_kwargs)
 
 
@@ -422,21 +458,20 @@ def mk_fnodes_from_fn_factories(
             )
 
 
+class dlft_factory_to_func_mapping(Mapping):
+    def __getitem__(self, item):
+        return dlft_factory_to_func(item)
+
+
 def _code_to_fnodes(src, func_src=dlft_factory_to_func):
-    if isinstance(func_src, Mapping):
-        name_to_func_map = func_src
-        func_src = partial(
-            dlft_factory_to_func,
-            name_to_func_map=name_to_func_map,
-            use_place_holder_fallback=False,
-        )
-    assert isinstance(func_src, Callable), f'func_src should be callable, or a mapping'
+    # Make all the funodes, but partial ones that don't have the func defined yet
     fnodes_factories = list(src_to_func_node_factory(src))
+    # "Inject" the actual functions
     return mk_fnodes_from_fn_factories(fnodes_factories, func_src)
 
 
 def _extract_name_from_single_func_def(src: str, default=None):
-    t = ast.parse(src)
+    t = robust_ast_parse(src)
     if (body := getattr(t, 'body')) is not None:
         first_element = next(iter(body))
         if (
@@ -447,9 +482,27 @@ def _extract_name_from_single_func_def(src: str, default=None):
     return default
 
 
+FuncSource = Union[Callable[[str], Callable], Mapping[str, Callable]]
+
+
+def _ensure_func_src(func_src: FuncSource) -> Callable[[str], Callable]:
+    if isinstance(func_src, Mapping):
+        name_to_func_map = func_src
+        func_src = partial(
+            dlft_factory_to_func,
+            name_to_func_map=name_to_func_map,
+            use_place_holder_fallback=False,
+        )
+    assert isinstance(func_src, Callable), f'func_src should be callable, or a mapping'
+    return func_src
+
+
 @double_up_as_factory
-def code_to_dag(src=None, *, func_src=dlft_factory_to_func, name=None) -> DAG:
+def code_to_dag(
+    src=None, *, func_src: FuncSource = dlft_factory_to_func, name: str = None
+) -> DAG:
     """Get a ``meshed.DAG`` from src code"""
+    func_src = _ensure_func_src(func_src)
     # Get a name for the dag (if src is a str
     if name is None:
         if isinstance(src, str):
@@ -458,6 +511,7 @@ def code_to_dag(src=None, *, func_src=dlft_factory_to_func, name=None) -> DAG:
             name = name_of_obj(src)
     # Pass on to _code_to_fnodes to get func nodes iterable needed to make DAG
     fnodes = _code_to_fnodes(src, func_src)
+    fnodes = list(fnodes)
     return DAG(fnodes, name=name)
 
 
